@@ -3,6 +3,8 @@
 require_relative "../spec_helper"
 
 describe "Blocking an IP" do
+  let(:notifications) { [] }
+
   before do
     Rack::Attack.blocklist_ip("1.2.3.4")
   end
@@ -19,22 +21,25 @@ describe "Blocking an IP" do
     assert_equal 200, last_response.status
   end
 
-  it "notifies when the request is blocked" do
-    notified = false
-    notification_type = nil
+  it "succeeds if IP is missing" do
+    get "/", {}, "REMOTE_ADDR" => ""
 
+    assert_equal 200, last_response.status
+  end
+
+  it "notifies when the request is blocked" do
     ActiveSupport::Notifications.subscribe("blocklist.rack_attack") do |_name, _start, _finish, _id, payload|
-      notified = true
-      notification_type = payload[:request].env["rack.attack.match_type"]
+      notifications.push(payload)
     end
 
     get "/", {}, "REMOTE_ADDR" => "5.6.7.8"
 
-    refute notified
+    assert notifications.empty?
 
     get "/", {}, "REMOTE_ADDR" => "1.2.3.4"
 
-    assert notified
-    assert_equal :blocklist, notification_type
+    assert_equal 1, notifications.size
+    notification = notifications.pop
+    assert_equal :blocklist, notification[:request].env["rack.attack.match_type"]
   end
 end
