@@ -4,11 +4,14 @@ require_relative "../../spec_helper"
 
 if defined?(::ConnectionPool) && defined?(::Dalli)
   require_relative "../../support/cache_store_helper"
-  require "timecop"
 
   describe "ActiveSupport::Cache::MemCacheStore (pooled) as a cache backend" do
     before do
-      Rack::Attack.cache.store = ActiveSupport::Cache::MemCacheStore.new(pool_size: 2)
+      Rack::Attack.cache.store = if ActiveSupport.gem_version >= Gem::Version.new("7.2.0")
+                                   ActiveSupport::Cache::MemCacheStore.new(pool: true)
+                                 else
+                                   ActiveSupport::Cache::MemCacheStore.new(pool_size: 2)
+                                 end
     end
 
     after do
