@@ -2,6 +2,7 @@
 
 require "bundler/setup"
 
+require "logger"
 require "minitest/autorun"
 require "minitest/pride"
 require "rack/test"
@@ -20,15 +21,15 @@ end
 
 safe_require "connection_pool"
 safe_require "dalli"
+safe_require "rails"
 safe_require "redis"
-safe_require "redis-activesupport"
 safe_require "redis-store"
 
-class MiniTest::Spec
+class Minitest::Spec
   include Rack::Test::Methods
 
   before do
-    if Object.const_defined?(:Rails) && Rails.respond_to?(:cache)
+    if Object.const_defined?(:Rails) && Rails.respond_to?(:cache) && Rails.cache.respond_to?(:clear)
       Rails.cache.clear
     end
   end
